@@ -43,7 +43,7 @@ class table_objects:
         for column in self.obj.columns:
             transit = 0
             for kwarg in kwargs:
-                if kwargs[kwarg] in column.data:
+                if kwargs[kwarg] == getattr(column, kwarg):
                     transit += 1
             if transit == need:
                 result.append(column)
@@ -109,7 +109,7 @@ class table_objects:
         for column in self.obj.columns:
             transit = 0
             for kwarg in kwargs:
-                if kwargs[kwarg] in column.data:
+                if kwargs[kwarg] == getattr(column, kwarg):
                     transit += 1
             if transit == need:
                 result.append(column)
@@ -151,7 +151,7 @@ class table_objects:
         for column in self.obj.columns:
             transit = 0
             for kwarg in kwargs:
-                if kwargs[kwarg] in column.data:
+                if kwargs[kwarg] == getattr(column, kwarg):
                     transit += 1
             if transit == need:
                 result.append(column)
